PCB Environment: Data Fields - Variables

PCB Environment 2

Loading...
Searching...
No Matches
Here is a list of all variables with links to the structures/unions they belong to:

### - p -

- P : CloneEnv, UIActions
- P0or1 : UIActions
- padstack : dsn::Pin
- padstacks : dsn::Data
- path : dsn::Shape
- Paths : UserSettings
- pcb : dsn::Data
- PerDisconnect : UserSettings
- PerVia : UserSettings
- PinFill : Palette
- PINK : Color
- PinLine : Palette
- pinref_x : dsn::Placement
- pinref_y : dsn::Placement
- pins : dsn::Image, dsn::Net, PCBItemSets, PCBoard
- PK : CloneEnv
- placements : dsn::Data, dsn::Image
- PointSize : UserSettings
- POISON : Color
- pos : GLWidget, py::DictIterator
- posDown : GLWidget
- PowerNet : Palette